/*
 * Clock identifiers for clock and power management.
 *
 * Copyright (C) 2021, 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

/* Identifiers for controllable "logical" or "abstract" clocks. Operations
   involving these clocks may operate on multiple "physical" or "specific"
   clocks. */

enum Clock_identifiers
{
  Clock_aic_bitclk,
  Clock_aic_pclk,
  Clock_can0,
  Clock_can1,
  Clock_cdbus,
  Clock_cim,
  Clock_cpu,
  Clock_ddr,
  Clock_dma,
  Clock_emac,
  Clock_external,
  Clock_hclock0,
  Clock_hclock2,
  Clock_hdmi,
  Clock_i2c,
  Clock_i2c0,
  Clock_i2c1,
  Clock_i2s,
  Clock_i2s0_rx,
  Clock_i2s0_tx,
  Clock_kbc,
  Clock_lcd,
  Clock_lcd_pixel,
  Clock_mac,
  Clock_main,
  Clock_mipi_csi,
  Clock_msc,
  Clock_msc0,
  Clock_msc1,
  Clock_none,
  Clock_otg,
  Clock_pclock,
  Clock_pll_A,
  Clock_pll_E,
  Clock_pll_M,
  Clock_pwm,
  Clock_pwm0,
  Clock_pwm1,
  Clock_scc,
  Clock_sfc,
  Clock_smb0,
  Clock_smb1,
  Clock_smb2,
  Clock_smb3,
  Clock_smb4,
  Clock_ssi,
  Clock_timer,
  Clock_uart0,
  Clock_uart1,
  Clock_uart2,
  Clock_uart3,
  Clock_udc,
  Clock_uhc,
  Clock_uprt,
  Clock_identifier_count, /* not a clock: limit for array definition */
  Clock_undefined,        /* not a clock: special value */
};

// vim: tabstop=2 expandtab shiftwidth=2
